import React, { useState, useEffect } from 'react'
import {dbCreateCollection, dbGetCollection, dbUploadRawTextFiles, dbUploadUrlFile, dbUploadRawHTMLFiles} from './database_util'


//General MUI imports
import Box from '@mui/material/Box';
import Button from '@mui/material/Button';
import CircularProgress from '@mui/material/CircularProgress';
import Backdrop from '@mui/material/Backdrop';
import TextField from '@mui/material/TextField';
import Autocomplete from '@mui/material/Autocomplete';

import Radio from '@mui/material/Radio';
import RadioGroup from '@mui/material/RadioGroup';
import FormControlLabel from '@mui/material/FormControlLabel';
import FormControl from '@mui/material/FormControl';
import FormLabel from '@mui/material/FormLabel';

//Dialog Imports
import Dialog from '@mui/material/Dialog';
import DialogTitle from '@mui/material/DialogTitle';
import DialogContent from '@mui/material/DialogContent';
import DialogActions from '@mui/material/DialogActions';

//icon
import LayersIcon from '@mui/icons-material/Layers';
import AddIcon from '@mui/icons-material/Add';

//List Imports
import List from '@mui/material/List';
import ListItemButton from '@mui/material/ListItemButton';
import ListItemIcon from '@mui/material/ListItemIcon';
import ListItemText from '@mui/material/ListItemText';
import Divider from '@mui/material/Divider';
import ListItem from '@mui/material/ListItem';

const CollectionList = (props) => {
    const [open, setOpen] = React.useState(false);
    const [newCollectionName, setNewCollectionName] = React.useState("false");
    const [newCollectionType, setNewCollectionType] = React.useState("text");

    const handleClose = () => {
        setOpen(false);
    };
    const handleOpen = () => {
        setNewCollectionName("");
        setOpen(true);
    };

    const handleSubmit = async (e) => {
        e.preventDefault();
        console.log(newCollectionType);
        let id = await dbCreateCollection(newCollectionName,newCollectionType);

        if (newCollectionType == "text"){
            await dbUploadRawTextFiles(id,props.collectionFileCache);
        } else if (newCollectionType == "url"){
            await dbUploadUrlFile(id,props.collectionFileCache)
        } else if (newCollectionType == "html"){
            await dbUploadRawHTMLFiles(id,props.collectionFileCache)
        } else {
            await dbUploadRawTextFiles(id,props.collectionFileCache);
        }

        let detailCollection = await dbGetCollection(id);
        console.log("handleSubmit",newCollectionName, id, detailCollection);
        props.onSelectCollection(detailCollection)
        props.onListUpdate()
        handleClose();
    };

    const handleSelect = async (id) => {
        let detailCollection = await dbGetCollection(id);
        props.onSelectCollection(detailCollection);
    }

    return (
        <Box sx={{
            "boxShadow":3
        }}>
            <List>
                <ListItem disablePadding key={999}>
                    <ListItemButton onClick={handleOpen}>
                        <ListItemIcon>
                            <AddIcon/>
                        </ListItemIcon>
                        <ListItemText primary={"Create New Collection"}/>
                    </ListItemButton>
                </ListItem>
                <Divider />
                {
                    props.collections.map(
                        (c) => {
                            console.log("BRUH",c)
                            return (
                            <ListItem disablePadding key={c["collection_id"]}>
                                <ListItemButton onClick={() => handleSelect(c["collection_id"])}>
                                    <ListItemIcon>
                                        <LayersIcon />
                                    </ListItemIcon>
                                    <ListItemText primary={c["collection_name"]}  secondary={c["collection_id"]}/>
                                </ListItemButton>
                            </ListItem>
                        )}
                    )
                }
                    
            </List>

            <Dialog
                open={open}
                onClose={handleClose}
                PaperProps={{
                    component:"form",
                    onSubmit: handleSubmit
                }}
            >
                <DialogTitle>Create New Collection</DialogTitle>
                
                <DialogContent>
                    <br/>
                    <TextField label="Collection Name" variant="outlined" required value={newCollectionName} onChange={(e)=> {setNewCollectionName(e.target.value)}}/>
                    <br/>
                    <Button component="label">
                        Upload File
                        <input type="file" name="fileUpload" onChange={props.onFileSelect} hidden/>
                    </Button>
                    <br/>
                    <RadioGroup
                        aria-labelledby="demo-radio-buttons-group-label"
                        defaultValue="female"
                        name="radio-buttons-group"
                        onChange={(e) => {setNewCollectionType(e.target.value)}}
                    >
                        <FormControlLabel value="text" control={<Radio />} label=".zip of text files" />
                        <FormControlLabel value="url" control={<Radio />} label=".txt file of urls" />
                        <FormControlLabel value="html" control={<Radio />} label=".zip of html files" />
                    </RadioGroup>

                    

                </DialogContent>
                <DialogActions>
                    <Button onClick={handleClose}>Cancel</Button>
                    <Button type="submit">Create</Button>
                </DialogActions>
            </Dialog>
        </Box>
    );
}

export default CollectionList;